        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 18 <br>1,7,11,13,15,18,19,27,28,31,33,34,35,37,43,47,48,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 11 <strong>control</strong><br>0,6,9,14,16,17,26,32,40,45,49';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>41</strong> miembros: 8 <br>10,12,24,29,38,41,42,46';}
       if(rr==2 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>2</strong> miembros: 7 <br>2,3,4,23,25,36,44';}
       if(rr==2 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>39</strong> miembros: 4 <br>5,20,21,39';}
       if(rr==2 && cc==6){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 3 <br>8,22,30';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 18 <br>1,7,11,13,15,18,19,27,28,31,33,34,35,37,43,47,48,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 11 <strong>control</strong><br>0,6,9,14,16,17,26,32,40,45,49';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>41</strong> miembros: 8 <br>10,12,24,29,38,41,42,46';}
       if(rr==9 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>2</strong> miembros: 7 <br>2,3,4,23,25,36,44';}
       if(rr==9 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>39</strong> miembros: 4 <br>5,20,21,39';}
       if(rr==9 && cc==6){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 3 <br>8,22,30';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 18 <br>1,7,11,13,15,18,19,27,28,31,33,34,35,37,43,47,48,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 11 <strong>control</strong><br>0,6,9,14,16,17,26,32,40,45,49';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>41</strong> miembros: 8 <br>10,12,24,29,38,41,42,46';}
       if(rr==10 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>2</strong> miembros: 7 <br>2,3,4,23,25,36,44';}
       if(rr==10 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>39</strong> miembros: 4 <br>5,20,21,39';}
       if(rr==10 && cc==6){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 3 <br>8,22,30';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 18 <br>1,7,11,13,15,18,19,27,28,31,33,34,35,37,43,47,48,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 11 <strong>control</strong><br>0,6,9,14,16,17,26,32,40,45,49';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>41</strong> miembros: 8 <br>10,12,24,29,38,41,42,46';}
       if(rr==11 && cc==4){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>2</strong> miembros: 7 <br>2,3,4,23,25,36,44';}
       if(rr==11 && cc==5){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>39</strong> miembros: 4 <br>5,20,21,39';}
       if(rr==11 && cc==6){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 3 <br>8,22,30';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 18 <br>1,7,11,13,15,18,19,27,28,31,33,34,35,37,43,47,48,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 11 <strong>control</strong><br>0,6,9,14,16,17,26,32,40,45,49';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>41</strong> miembros: 8 <br>10,12,24,29,38,41,42,46';}
       if(rr==12 && cc==4){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>2</strong> miembros: 7 <br>2,3,4,23,25,36,44';}
       if(rr==12 && cc==5){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>39</strong> miembros: 4 <br>5,20,21,39';}
       if(rr==12 && cc==6){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 3 <br>8,22,30';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 18 <br>1,7,11,13,15,18,19,27,28,31,33,34,35,37,43,47,48,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 11 <strong>control</strong><br>0,6,9,14,16,17,26,32,40,45,49';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>41</strong> miembros: 8 <br>10,12,24,29,38,41,42,46';}
       if(rr==13 && cc==4){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>2</strong> miembros: 7 <br>2,3,4,23,25,36,44';}
       if(rr==13 && cc==5){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>39</strong> miembros: 4 <br>5,20,21,39';}
       if(rr==13 && cc==6){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 3 <br>8,22,30';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 18 <br>1,7,11,13,15,18,19,27,28,31,33,34,35,37,43,47,48,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 11 <strong>control</strong><br>0,6,9,14,16,17,26,32,40,45,49';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>41</strong> miembros: 8 <br>10,12,24,29,38,41,42,46';}
       if(rr==14 && cc==4){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>2</strong> miembros: 7 <br>2,3,4,23,25,36,44';}
       if(rr==14 && cc==5){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>39</strong> miembros: 4 <br>5,20,21,39';}
       if(rr==14 && cc==6){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 3 <br>8,22,30';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 18 <br>1,7,11,13,15,18,19,27,28,31,33,34,35,37,43,47,48,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 11 <strong>control</strong><br>0,6,9,14,16,17,26,32,40,45,49';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>41</strong> miembros: 8 <br>10,12,24,29,38,41,42,46';}
       if(rr==15 && cc==4){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>2</strong> miembros: 7 <br>2,3,4,23,25,36,44';}
       if(rr==15 && cc==5){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>39</strong> miembros: 4 <br>5,20,21,39';}
       if(rr==15 && cc==6){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 3 <br>8,22,30';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 18 <br>1,7,11,13,15,18,19,27,28,31,33,34,35,37,43,47,48,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 11 <strong>control</strong><br>0,6,9,14,16,17,26,32,40,45,49';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>41</strong> miembros: 8 <br>10,12,24,29,38,41,42,46';}
       if(rr==16 && cc==4){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>2</strong> miembros: 7 <br>2,3,4,23,25,36,44';}
       if(rr==16 && cc==5){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>39</strong> miembros: 4 <br>5,20,21,39';}
       if(rr==16 && cc==6){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260523 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 3 <br>8,22,30';}
}
